==> components-1.0.21.tgz: package/src/components/developer/tabela-developer.tsx <==
/* eslint-disable @typescript-eslint/no-explicit-any */
import { DropdownMenuTrigger } from "@radix-ui/react-dropdown-menu";
import { Card, CardContent, CardHeader, CardTitle } from "../ui/card";
import { DropdownMenu, DropdownMenuContent, DropdownMenuItem, DropdownMenuLabel, DropdownMenuRadioGroup, DropdownMenuRadioItem, DropdownMenuSeparator } from "../ui/dropdown-menu";
import { Input } from "../ui/input";
import { Config } from "../../assets/config";
import { Search } from "../../assets/search";
import { ArrowLeft } from "../../assets/arrowLeft";
import { motion, AnimatePresence } from 'framer-motion';
import { useState } from "react";

interface TabelaDeveloperProps {
    title?: string;
    subtitle?: string;
    types: string[];
    selectedType?: string;
    onTypeSelect: (type: string) => void;
    columnsContent: ColumnContent[];
    tabelaContent: any[];
}

interface ColumnContent {
    title: string;
    key: string;
}

export default function TabelaDeveloper({
    title = 'Tabela',
    subtitle = 'Esta é uma tabela de exemplo',
    types,
    selectedType,
    onTypeSelect,
    columnsContent,
    tabelaContent
}: TabelaDeveloperProps): JSX.Element {
    const [isOpen, setIsOpen] = useState(false);
    const [filteredTabelaContent, setFilteredTabelaContent] = useState(tabelaContent);
    const [searchText, setSearchText] = useState("");

    const toggleInput = () => {
        setIsOpen(!isOpen);
    };

    const handleTypeSelect = (type: string) => {
        // Atualiza o tipo selecionado
        onTypeSelect(type);

        let filteredData = tabelaContent;

        // Filtra os dados com base no tipo selecionado
        if (type !== 'Todos') {
            filteredData = filteredData.filter(item => {
                for (const key in item) {
                    if (typeof item[key] !== 'string') continue;
                    if (item[key].toLowerCase() === type.toLowerCase()) return true;
                }
                return false;
            });
        }

        // Filtra os dados com base no texto de pesquisa
        if (searchText) {
            filteredData = filteredData.filter(item => {
                for (const key in item) {
                    if (typeof item[key] !== 'string') continue;
                    if (item[key].toLowerCase().includes(searchText.toLowerCase())) return true;
                }
                return false;
            });
        }

        setFilteredTabelaContent(filteredData);
    };

    return (
        <Card className="w-full rounded-[16px] h-[461px] ">
            <CardHeader className="flex flex-row justify-between relative items-center">
                <div className='w-full'>
                    <CardTitle className=" w-fit  rounded-full text-[16px] text-[#344054] font-sf-pro-text-bold">{title}</CardTitle>
                    <CardTitle className=" w-fit  rounded-full text-[12px] text-[#667085] font-normal">{subtitle}</CardTitle>
                </div>
                <div className='flex flex-row w-fit gap-5'>
                    <AnimatePresence>
                        {isOpen && (
                            <div className='flex flex-row w-[90%] h-[50px] absolute bg-[#ffffff] left-0 items-center'>
                                <motion.div
                                    initial={{ width: 0 }}
                                    animate={{ width: '100%' }}
                                    exit={{ width: 0 }}
                                    className="flex flex-row w-full h-[50px] bg-[#ffffff] items-center"
                                >
                                    <div className="ml-5 mr-5 hover:opacity-60 cursor-pointer" onClick={toggleInput}>
                                        <ArrowLeft color="#d0d5dd" />
                                    </div>
                                    <Input
                                        type="text"
                                        placeholder="Procure por valor"
                                        className='h-[40px] w-full border-0 shadow-none'
                                        value={searchText}
                                        onChange={(e) => {
                                            setSearchText(e.target.value);
                                            handleTypeSelect(selectedType || 'Todos');
                                        }}
                                    />
                                </motion.div>
                            </div>
                        )}
                    </AnimatePresence>
                    <div className='flex flex-row w-full'>
                        <div className='flex flex-row items-center h-[40px] w-auto text-nowrap'>
                            {types.map((type, index) => (
                                <div
                                    key={index}
                                    className={`px-[20px] py-[15px] text-[#98A2B3] cursor-pointer ${selectedType === type ? 'text-blue-500 border-b-[2px] border-blue-500' : 'text-[#98A2B3]'}`}
                                    onClick={() => handleTypeSelect(type)}
                                >
                                    {type}
                                </div>
                            ))}
                        </div>
                    </div>
                    <div className='flex flex-row w-full items-center '>
                        <div className='h-[23px] w-[2px] bg-[#F2F4F7]' />
                    </div>
                    <div className='flex flex-row gap-[16px] w-fit'>
                        <div className='flex flex-row items-center h-[40px] hover:opacity-60 cursor-pointer ' onClick={toggleInput}>
                            <Search color="#d0d5dd" />
                        </div>
                        <div className='flex flex-row items-center h-[40px]'>
                            <DropdownMenu>
                                <DropdownMenuTrigger className="hover:opacity-60 cursor-pointer"><Config color="#d0d5dd" /></DropdownMenuTrigger>
                                <DropdownMenuContent>
                                    <DropdownMenuLabel className='font-sf-pro-text-bold'>Ações</DropdownMenuLabel>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuItem>Imprimir</DropdownMenuItem>
                                    <DropdownMenuItem>Exportar PDF</DropdownMenuItem>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuLabel className='font-sf-pro-text-bold'>Exibir últimos</DropdownMenuLabel>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuRadioGroup >
                                        <DropdownMenuRadioItem value="15day">15 dias</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="20day">20 dias</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="1month">1 mês</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="15day">Completo</DropdownMenuRadioItem >
                                    </DropdownMenuRadioGroup>
                                </DropdownMenuContent>
                            </DropdownMenu>
                        </div>
                    </div>
                </div>
            </CardHeader>
            <CardContent className="flex flex-col gap-[20px] p-0 h-[475px] overflow-y-auto w-full">
                <div>
                    <div className="flex  border-y border-[#f2f4f7] h-[49px] justify-between items-center py-5 px-6">
                        {columnsContent.map((column, index) => (
                            <div key={index} className="flex w-96 text-[12px] text-[#344054]">
                                {column.title}
                            </div>
                        ))}
                    </div>
                    <div className="overflow-auto max-h-[310px]">
                        {filteredTabelaContent.map((tabela, index) => (
                            <div key={index} className="flex text-[#344054] text-[14px] border-b border-[#f2f4f7] h-[64px] justify-between items-center py-5 px-6 ">
                                {columnsContent.map((column, columnIndex) => (
                                    <div key={columnIndex}
                                        className={`flex w-96 
                                        ${tabela.action ? ` ${columnIndex === columnsContent.length - 1 ? 'justify-end' : ''}` : ''}
                                        `}
                                    >
                                        {tabela[column.key] ? tabela[column.key] : '-'}
                                    </div>
                                ))}
                            </div>
                        ))}
                    </div>
                </div>
            </CardContent>
        </Card >
    );
}

==> components-1.0.32.tgz: package/src/components/developer/tabela-developer.tsx <==
/* eslint-disable @typescript-eslint/no-explicit-any */
import { DropdownMenuTrigger } from "@radix-ui/react-dropdown-menu";
import { Card, CardContent, CardHeader, CardTitle } from "../ui/card";
import { DropdownMenu, DropdownMenuContent, DropdownMenuItem, DropdownMenuLabel, DropdownMenuRadioGroup, DropdownMenuRadioItem, DropdownMenuSeparator } from "../ui/dropdown-menu";
import { Input } from "../ui/input";
import { Config } from "../../assets/config";
import { Search } from "../../assets/search";
import { ArrowLeft } from "../../assets/arrowLeft";
import { motion, AnimatePresence } from 'framer-motion';
import { useState } from "react";

interface TabelaDeveloperProps {
    title?: string;
    subtitle?: string;
    types: string[];
    selectedType?: string;
    onTypeSelect: (type: string) => void;
    columnsContent: ColumnContent[];
    tabelaContent: any[];
}

interface ColumnContent {
    title: string;
    key: string;
}

export default function TabelaDeveloper({
    title = 'Tabela',
    subtitle = 'Esta é uma tabela de exemplo',
    types,
    selectedType,
    onTypeSelect,
    columnsContent,
    tabelaContent
}: TabelaDeveloperProps): JSX.Element {
    const [isOpen, setIsOpen] = useState(false);
    const [filteredTabelaContent, setFilteredTabelaContent] = useState(tabelaContent);
    const [searchText, setSearchText] = useState("");

    const toggleInput = () => {
        setIsOpen(!isOpen);
    };

    const handleTypeSelect = (type: string) => {
        // Atualiza o tipo selecionado
        onTypeSelect(type);

        let filteredData = tabelaContent;

        // Filtra os dados com base no tipo selecionado
        if (type !== 'Todos') {
            filteredData = filteredData.filter(item => {
                for (const key in item) {
                    if (typeof item[key] !== 'string') continue;
                    if (item[key].toLowerCase() === type.toLowerCase()) return true;
                }
                return false;
            });
        }

        // Filtra os dados com base no texto de pesquisa
        if (searchText) {
            filteredData = filteredData.filter(item => {
                for (const key in item) {
                    if (typeof item[key] !== 'string') continue;
                    if (item[key].toLowerCase().includes(searchText.toLowerCase())) return true;
                }
                return false;
            });
        }

        setFilteredTabelaContent(filteredData);
    };

    return (
        <Card className="w-full rounded-[16px] h-[461px] ">
            <CardHeader className="flex flex-row justify-between relative items-center">
                <div className='w-full'>
                    <CardTitle className=" w-fit  rounded-full text-[16px] text-[#344054] font-sf-pro-text-bold">{title}</CardTitle>
                    <CardTitle className=" w-fit  rounded-full text-[12px] text-[#667085] font-normal">{subtitle}</CardTitle>
                </div>
                <div className='flex flex-row w-fit gap-5'>
                    <AnimatePresence>
                        {isOpen && (
                            <div className='flex flex-row w-[90%] h-[50px] absolute bg-[#ffffff] left-0 items-center'>
                                <motion.div
                                    initial={{ width: 0 }}
                                    animate={{ width: '100%' }}
                                    exit={{ width: 0 }}
                                    className="flex flex-row w-full h-[50px] bg-[#ffffff] items-center"
                                >
                                    <div className="ml-5 mr-5 hover:opacity-60 cursor-pointer" onClick={toggleInput}>
                                        <ArrowLeft color="#d0d5dd" />
                                    </div>
                                    <Input
                                        type="text"
                                        placeholder="Procure por valor"
                                        className='h-[40px] w-full border-0 shadow-none'
                                        value={searchText}
                                        onChange={(e) => {
                                            setSearchText(e.target.value);
                                            handleTypeSelect(selectedType || 'Todos');
                                        }}
                                    />
                                </motion.div>
                            </div>
                        )}
                    </AnimatePresence>
                    <div className='flex flex-row w-full'>
                        <div className='flex flex-row items-center h-[40px] w-auto text-nowrap'>
                            {types.map((type, index) => (
                                <div
                                    key={index}
                                    className={`px-[20px] py-[15px] text-[#98A2B3] cursor-pointer ${selectedType === type ? 'text-blue-500 border-b-[2px] border-blue-500' : 'text-[#98A2B3]'}`}
                                    onClick={() => handleTypeSelect(type)}
                                >
                                    {type}
                                </div>
                            ))}
                        </div>
                    </div>
                    <div className='flex flex-row w-full items-center '>
                        <div className='h-[23px] w-[2px] bg-[#F2F4F7]' />
                    </div>
                    <div className='flex flex-row gap-[16px] w-fit'>
                        <div className='flex flex-row items-center h-[40px] hover:opacity-60 cursor-pointer ' onClick={toggleInput}>
                            <Search color="#d0d5dd" />
                        </div>
                        <div className='flex flex-row items-center h-[40px]'>
                            <DropdownMenu>
                                <DropdownMenuTrigger className="hover:opacity-60 cursor-pointer"><Config color="#d0d5dd" /></DropdownMenuTrigger>
                                <DropdownMenuContent>
                                    <DropdownMenuLabel className='font-sf-pro-text-bold'>Ações</DropdownMenuLabel>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuItem>Imprimir</DropdownMenuItem>
                                    <DropdownMenuItem>Exportar PDF</DropdownMenuItem>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuLabel className='font-sf-pro-text-bold'>Exibir últimos</DropdownMenuLabel>
                                    <DropdownMenuSeparator />
                                    <DropdownMenuRadioGroup >
                                        <DropdownMenuRadioItem value="15day">15 dias</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="20day">20 dias</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="1month">1 mês</DropdownMenuRadioItem >
                                        <DropdownMenuRadioItem value="15day">Completo</DropdownMenuRadioItem >
                                    </DropdownMenuRadioGroup>
                                </DropdownMenuContent>
                            </DropdownMenu>
                        </div>
                    </div>
                </div>
            </CardHeader>
            <CardContent className="flex flex-col gap-[20px] p-0 h-[475px] overflow-y-auto w-full">
                <div>
                    <div className="flex border-t border-b border-[#f2f4f7] h-[49px] justify-between p-5 items-center ">
                        {columnsContent.map((column, index) => (
                            <div key={index} className="flex w-96 text-[12px] text-[#344054]">
                                {column.title}
                            </div>
                        ))}
                    </div>
                    <div className="overflow-auto max-h-[310px]">
                        {filteredTabelaContent.map((tabela, index) => (
                            <div key={index} className="flex text-[#344054] text-[14px] border-b border-[#f2f4f7] h-[64px] justify-between items-center p-5  ">
                                {columnsContent.map((column, columnIndex) => (
                                    <div key={columnIndex}
                                        className={`flex w-96 
                                        ${tabela.action ? ` ${columnIndex === columnsContent.length - 1 ? 'justify-end' : ''}` : ''}
                                        `}
                                    >
                                        {tabela[column.key] ? tabela[column.key] : '-'}
                                    </div>
                                ))}
                            </div>
                        ))}
                    </div>
                </div>
            </CardContent>
        </Card >
    );
}
